/*!
# LemonMath
LemonMath is a Rust library for mathematics.

## *why?*
Why is this library needed?
This library was created because I *personally* needed a library for mathematics,
and I wanted to create the best mathematics library I could.

## Features

* [Matrices](https://docs.rs/lemonmath/0.1.0/lemonmath/matrices/index.html)
* [Vectors](https://docs.rs/lemonmath/0.1.0/lemonmath/vectors/index.html)
* [Fraction](https://docs.rs/lemonmath/0.1.0/lemonmath/fraction/index.html)
* [Helper](https://docs.rs/lemonmath/0.1.0/lemonmath/helper/index.html)

## Usage

There is fractions, vectors, and matrices.
Currently vectors and matrices are work in progress and will be updated soon.

## License

[GNU License v3.0](https://www.gnu.org/licenses/gpl-3.0.en.html)
!*/

pub mod matrices;
pub mod vectors;
pub mod helper;
pub mod fraction;